@@ -1,6 +1,6 @@
 #' @rawNamespace import(data.table, except = transpose)
 #' @importFrom R6 R6Class
-#' @importFrom mlr3 TaskClassif TaskRegr Resampling as_data_backend assert_task rsmp tsk rsmps lrn msr
+#' @importFrom mlr3 TaskClassif TaskRegr Resampling as_data_backend assert_task rsmp tsk rsmps lrn msr mlr_resamplings
 #' @import mlr3misc
 #' @import checkmate
 #' @import paradox
@@ -38,55 +38,55 @@
 #' `r format_bib("zhao2002")`
 "_PACKAGE"
 
+utils::globalVariables(c(
+  "row_id", "cookfarm_sample", "ecuador", "diplodia",
+  "resampling", "task", "indicator", "fold", "id", "type"))
+
 register_mlr3 = function() { # nocov start
   # reflections ----------------------------------------------------------------
+
   x = utils::getFromNamespace("mlr_reflections", ns = "mlr3")
 
-  if (!grepl("ST", x$task_types[, "task"])) {
-    x = utils::getFromNamespace("mlr_reflections", ns = "mlr3")
+  x$task_types = setkeyv(rbind(x$task_types, rowwise_table(
+    ~type, ~package, ~task, ~learner, ~prediction, ~measure,
+    "regr", "mlr3spatiotempcv", "TaskRegrST", "LearnerRegr", "PredictionRegr",
+    "MeasureRegr",
 
-    x$task_types = setkeyv(rbind(x$task_types, rowwise_table(
-      ~type, ~package, ~task, ~learner, ~prediction, ~measure,
-      "regr", "mlr3spatiotempcv", "TaskRegrST", "LearnerRegr", "PredictionRegr",
-      "MeasureRegr",
+    "classif", "mlr3spatiotempcv", "TaskClassifST", "LearnerClassif",
+    "PredictionClassif", "MeasureClassif"
+  )), "type")
 
-      "classif", "mlr3spatiotempcv", "TaskClassifST", "LearnerClassif",
-      "PredictionClassif", "MeasureClassif"
-    )), "type")
+  # append "coordinates" to col_roles
+  x$task_col_roles$classif_st = append(x$task_col_roles$classif, "coordinates")
+  x$task_col_roles$regr_st = append(x$task_col_roles$regr, "coordinates")
 
-    # append "coordinates" to col_roles
-    x$task_col_roles$classif_st = append(x$task_col_roles$classif, "coordinates")
-    x$task_col_roles$regr_st = append(x$task_col_roles$regr, "coordinates")
+  # tasks --------------------------------------------------------------------
 
-    # tasks --------------------------------------------------------------------
+  mlr_tasks = utils::getFromNamespace("mlr_tasks", ns = "mlr3")
 
-    mlr_tasks = utils::getFromNamespace("mlr_tasks", ns = "mlr3")
+  mlr_tasks$add("ecuador", load_task_ecuador)
+  mlr_tasks$add("diplodia", load_task_diplodia)
+  mlr_tasks$add("cookfarm", load_task_cookfarm)
 
-    mlr_tasks$add("ecuador", load_task_ecuador)
-    mlr_tasks$add("diplodia", load_task_diplodia)
-    mlr_tasks$add("cookfarm", load_task_cookfarm)
+  # resampling methods ---------------------------------------------------------
 
-    # resampling methods ---------------------------------------------------------
-
-    mlr_resamplings = utils::getFromNamespace("mlr_resamplings", ns = "mlr3")
-    mlr_resamplings$add("spcv_block", ResamplingSpCVBlock)
-    mlr_resamplings$add("spcv_buffer", ResamplingSpCVBuffer)
-    mlr_resamplings$add("sptcv_cstf", ResamplingSptCVCstf)
-    mlr_resamplings$add("sptcv_cluto", ResamplingSptCVCluto)
-    mlr_resamplings$add("spcv_coords", ResamplingSpCVCoords)
-    mlr_resamplings$add("spcv_env", ResamplingSpCVEnv)
-
-    mlr_resamplings$add("repeated_spcv_coords", ResamplingRepeatedSpCVCoords)
-    mlr_resamplings$add("repeated_spcv_env", ResamplingRepeatedSpCVEnv)
-    mlr_resamplings$add("repeated_spcv_block", ResamplingRepeatedSpCVBlock)
-    mlr_resamplings$add("repeated_sptcv_cluto", ResamplingRepeatedSptCVCluto)
-    mlr_resamplings$add("repeated_sptcv_cstf", ResamplingRepeatedSptCVCstf)
-  }
-
-  utils::globalVariables(c(
-    "row_id", "cookfarm_sample", "ecuador", "diplodia",
-    "resampling", "task", "indicator", "fold", "id", "type"))
+  mlr_resamplings = utils::getFromNamespace("mlr_resamplings", ns = "mlr3")
+  mlr_resamplings$add("spcv_block", ResamplingSpCVBlock)
+  mlr_resamplings$add("spcv_buffer", ResamplingSpCVBuffer)
+  mlr_resamplings$add("spcv_disc", ResamplingSpCVDisc)
+  mlr_resamplings$add("spcv_tiles", ResamplingSpCVTiles)
+  mlr_resamplings$add("sptcv_cstf", ResamplingSptCVCstf)
+  mlr_resamplings$add("sptcv_cluto", ResamplingSptCVCluto)
+  mlr_resamplings$add("spcv_coords", ResamplingSpCVCoords)
+  mlr_resamplings$add("spcv_env", ResamplingSpCVEnv)
 
+  mlr_resamplings$add("repeated_spcv_coords", ResamplingRepeatedSpCVCoords)
+  mlr_resamplings$add("repeated_spcv_env", ResamplingRepeatedSpCVEnv)
+  mlr_resamplings$add("repeated_spcv_block", ResamplingRepeatedSpCVBlock)
+  mlr_resamplings$add("repeated_spcv_disc", ResamplingRepeatedSpCVDisc)
+  mlr_resamplings$add("repeated_spcv_tiles", ResamplingRepeatedSpCVTiles)
+  mlr_resamplings$add("repeated_sptcv_cluto", ResamplingRepeatedSptCVCluto)
+  mlr_resamplings$add("repeated_sptcv_cstf", ResamplingRepeatedSptCVCstf)
 }
 
 .onLoad = function(libname, pkgname) { # nolint
